/* AlignMatchViewer.java
 *
 * created: Tue Feb 13 2001
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 2001  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/pathsoft/repository/powmap/diana/components/AlignMatchViewer.java,v 1.2 2001/02/23 14:51:26 kmr Exp $
 */

package diana.components;

import diana.*;

import java.awt.*;
import java.awt.event.*;

/**
 *  A component for viewing AlignMatchVectors selected in an AlignmentViewer.
 *
 *  @author Kim Rutherford
 *  @version $Id: AlignMatchViewer.java,v 1.2 2001/02/23 14:51:26 kmr Exp $
 **/

public class AlignMatchViewer extends Frame {
  /**
   *  Create a new AlignMatchViewer which shows the given matches.
   *  @param alignment_viewer The AlignmentViewer to call alignAt () and
   *    setSelection () on when the user clicks on a match.  
   *  @param matches The Vector of AlignMatch objects to show.
   **/
  public AlignMatchViewer (final AlignmentViewer alignment_viewer,
                           final AlignMatchVector matches) {
    this.alignment_viewer = alignment_viewer;
    this.matches = matches;

    final List list = new List ();

    list.setBackground (Color.white);

    add (list, "Center");

    final Panel panel = new Panel ();

    final Button close_button = new Button ("Close");

    panel.add (close_button);
    close_button.addActionListener (new ActionListener () {
      public void actionPerformed (ActionEvent e) {
        AlignMatchViewer.this.dispose ();
      }
    });

    close_button.addActionListener (new ActionListener () {
      public void actionPerformed (ActionEvent e) {
        AlignMatchViewer.this.dispose ();
      }
    });

    add (panel, "South");

    addWindowListener (new WindowAdapter () {
      public void windowClosing (WindowEvent event) {
        AlignMatchViewer.this.dispose ();
      }
    });

    pack ();

    for (int i = 0 ; i < matches.size () ; ++i) {
      final AlignMatch this_align_match = matches.elementAt (i);

      String match_string =
        this_align_match.getQuerySequenceStart () + ".." +
        this_align_match.getQuerySequenceEnd () + " -> " +
        this_align_match.getSubjectSequenceStart () + ".." +
        this_align_match.getSubjectSequenceEnd () + " score " +
        this_align_match.getScore ();

      if (this_align_match.isRevMatch ()) {
        match_string = "Rev: " + match_string;
      }

      list.add (match_string);
    }

    list.addItemListener (new ItemListener () {
      public void itemStateChanged (final ItemEvent _) {
        final int item_number = list.getSelectedIndex ();

        final AlignMatch selected_match = matches.elementAt (item_number);

        alignment_viewer.setSelection (selected_match);
        alignment_viewer.alignAt (selected_match);
      }
    });

    final Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();

    int screen_height = screen.height;
    int screen_width = screen.width;

    if (screen_height <= 600) {
      setSize (300, screen_height * 9 / 10);
    } else {
      setSize (300, screen_height - 200);
    }

    setLocation (new Point (screen.width - getSize ().width - 5,
                            (screen.height - getSize ().height) / 2));
  }

  /**
   *  The AlignmentViewer to call alignAt () and setSelection () on when the
   *  user clicks on a match.
   **/
  private AlignmentViewer alignment_viewer = null;

  /**
   *  The Vector of AlignMatch objects that was passed to the constructor.
   **/
  private AlignMatchVector matches = null;
}
